@@ -1,13 +1,22 @@
 from .version import __version__
 from . import constants
 from . import utilities
-from .io import (
-    InputProvider,
-    OutputProvider,
+
+from .channel_mappings import (
     ChannelMapping,
     dict_or_channel_mapping_to_channel_mapping,
 )
-from .audio import SimpleAudioObject, NestedAudioObject, AudioHost
+from .audio import (
+    SimpleAudioObject,
+    NestedAudioObject,
+    AudioObjectWithDecibel,
+    AudioHost,
+)
+from .io import (
+    InputProvider,
+    OutputProvider,
+    PyoObjectMixer,
+)
 from .parameters import Parameter
 from .modules import (
     Module,
@@ -21,3 +30,4 @@ from .backends import Backend
 from . import parsers
 from . import ui
 from .boot import start_loop_from_jinja2_file_path, start_loop_from_toml_str
+from . import unit_tests
