@@ -9,8 +9,10 @@ import walkman
 CONFIGURE_KEY = "configure"
 CONFIGURE_NAME_KEY = "name"
 CONFIGURE_AUDIO_KEY = "audio"
+CONFIGURE_AUDIO_CHANNEL_COUNT_KEY = "channel_count"
 CONFIGURE_INPUT_KEY = "input"
 CONFIGURE_OUTPUT_KEY = "output"
+CONFIGURE_OUTPUT_CHANNEL_MAPPING_KEY = "channel_mapping"
 CONFIGURE_MODULE_KEY = "module"
 CONFIGURE_MODULE_REPLICATION_COUNT_KEY = "replication_count"
 
@@ -31,6 +33,14 @@ class UnusedSpecificationWarning(Warning):
     pass
 
 
+class OverrideExplicitChannelCountWarning(Warning):
+    def __init__(self, _: str = ""):
+        super().__init__(
+            "WALKMAN overrides explicitly set value "
+            f"of '{CONFIGURE_MODULE_REPLICATION_COUNT_KEY}'"
+        )
+
+
 def warn_not_used_configuration_content(toml_block: dict, block_name: str):
     if toml_block:
         formatted_toml_block = "\t>>> ".join(str(toml_block).splitlines(True))
@@ -84,7 +94,6 @@ def configure_module_block_and_audio_object_to_module_dict(
             {module_name: replication_configuration}
         )
     return walkman.ModuleDict.from_audio_objects_and_module_configuration(
-        audio_host,
         input_provider,
         output_provider,
         module_name_to_replication_configuration_dict,
@@ -108,6 +117,15 @@ def configure_block_to_global_state_object_tuple(
 
     warn_not_used_configuration_content(configure_block, "configure")
 
+    if CONFIGURE_OUTPUT_CHANNEL_MAPPING_KEY in output_block:
+        output_channel_mapping = output_block[
+            CONFIGURE_OUTPUT_CHANNEL_MAPPING_KEY
+        ] = walkman.ChannelMapping(output_block[CONFIGURE_OUTPUT_CHANNEL_MAPPING_KEY])
+        channel_count = output_channel_mapping.maxima_right_channel
+        if CONFIGURE_AUDIO_CHANNEL_COUNT_KEY in audio_block:
+            warnings.warn("", OverrideExplicitChannelCountWarning)
+        audio_block[CONFIGURE_AUDIO_CHANNEL_COUNT_KEY] = channel_count
+
     audio_host = walkman.AudioHost(**audio_block)
     input_provider = walkman.InputProvider.from_data(**input_block)
     output_provider = walkman.OutputProvider(**output_block)
@@ -179,4 +197,9 @@ def jinja2_file_path_to_backend(jinja2_file_path: str) -> walkman.Backend:
     environment = jinja2.Environment(loader=jinja2.FileSystemLoader("./"))
     template = environment.get_template(jinja2_file_path)
     toml_str = template.render()
+    walkman.constants.LOGGER.critical(
+        "WALKMAN converted jinja2 template to the following toml file:\n\n{}".format(
+            "\t".join([f"{line_index}: {line}" for line_index, line in enumerate(str(toml_str).splitlines(True))])
+        )
+    )
     return toml_str_to_backend(toml_str)
